#! /usr/bin/env python

# MJ Pomraning <mjp@pilcrow.madison.wi.us>
# 03 Apr 2001
# dnslook 0.11

from os import chdir, stat
from distutils.core import setup, Extension
from distutils.command.build import build
from distutils.spawn import spawn

DJBDNS  = 'djbdns-1.05'
DJBDNSLINK = ['iopause.o','dns.a','env.a','alloc.a','unix.a','byte.a','libtai.a']
EXTRAOB = map(lambda a: DJBDNS + '/' + a, DJBDNSLINK)

# djb has heavily augmented make(1) process for his packages, which
# we'll hide beneath the distutils interface

class djbmake (build):

    def run(self):

        self.build_cdb()
        build.run(self)


    def build_cdb(self):
        global DJBDNSLINK

        try:
            stat(DJBDNS)
            return None  ## already done w/ this
        except OSError:
            pass

        spawn(['tar', '-xf', DJBDNS + '.tar' ], search_path = 1)
        spawn(['patch', '-p0', '-i', 'djbdns-dnsns.diff' ], search_path = 1)
        chdir( DJBDNS )
        self.twiddle_conf()
        spawn(['make'] + DJBDNSLINK, search_path = 1)
        chdir( '..' )


    def twiddle_conf(self):

        conf_cc = open('conf-cc', 'r').readline()
        if conf_cc[-1] == '\n':
            conf_cc = conf_cc[0:-1]
        open('conf-cc', 'w+').write(conf_cc + " -fPIC\n")



# class djbmake

setup (# Distribution meta-data
        name = "dnslook",
        version = "0.11",
        description = "High-level DNS lookup routines",
        author = "MJ Pomraning",
        author_email = "mjp@pilcrow.madison.wi.us",
        long_description = \
'''dnslook is an adaptation of D. J. Bernstein's easy-to-use, high-level
DNS lookup routines from the djbdns package.

IP and name lookup (with qualification) functions offer an able
alternative to the socket.gethostby* interface.  Further, MX/NS/TXT
lookups are supported, as well as IP address packing (for communication
with programs that expect struct in_addr), making dnslook well-suited
to commonly scripted DNS tasks.''',

        cmdclass = {'build': djbmake},
        ext_modules = [ Extension(
                            "dnslook",
                            ["dnslookmod.c"],
                            include_dirs=[ DJBDNS + '/' ], 
                            extra_objects = EXTRAOB
                        ) 
                      ],
        url = "",
      )

